ete2.treeview._mainwindow

Package ete2 :: Package treeview :: Module _mainwindow |
[hide private]
[frames] | no frames]

# Source Code for Module ete2.treeview._mainwindow

      1  # #START_LICENSE###########################################################
      2  #
      3  # Copyright (C) 2009 by Jaime Huerta Cepas. All rights reserved.
      4  # email: jhcepas@gmail.com
      5  #
      6  # This file is part of the Environment for Tree Exploration program (ETE).
      7  # http://ete.cgenomics.org
      8  #
      9  # ETE is free software: you can redistribute it and/or modify it
     10  # under the terms of the GNU General Public License as published by
     11  # the Free Software Foundation, either version 3 of the License, or
     12  # (at your option) any later version.
     13  #
     14  # ETE is distributed in the hope that it will be useful,
     15  # but WITHOUT ANY WARRANTY; without even the implied warranty of
     16  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     17  # GNU General Public License for more details.
     18  #
     19  # You should have received a copy of the GNU General Public License
     20  # along with ETE.  If not, see <http://www.gnu.org/licenses/>.
     21  #
     22  # #END_LICENSE#############################################################
     23  __VERSION__="ete2-2.0rev90"
     24  # -*- coding: utf-8 -*-
     25
     26  # Form implementation generated from reading ui file 'ete_qt4app.ui'
     27  #
     28  # Created: Mon Sep 14 11:11:49 2009
     29  #      by: PyQt4 UI code generator 4.5.4
     30  #
     31  # WARNING! All changes made in this file will be lost!
     32  try:
     33      from PyQt4 import QtCore, QtGui
     34  except ImportError:
     35      import QtCore, QtGui
     36
     37 -class Ui_MainWindow(object):
     38 -    def setupUi(self, MainWindow):
     39          MainWindow.setObjectName("MainWindow")
     40          MainWindow.resize(673, 493)
     41          self.centralwidget = QtGui.QWidget(MainWindow)
     42          self.centralwidget.setGeometry(QtCore.QRect(0, 58, 673, 411))
     43          self.centralwidget.setObjectName("centralwidget")
     44          MainWindow.setCentralWidget(self.centralwidget)
     45          self.menubar = QtGui.QMenuBar(MainWindow)
     46          self.menubar.setGeometry(QtCore.QRect(0, 0, 673, 24))
     47          self.menubar.setObjectName("menubar")
     48          self.menuFile = QtGui.QMenu(self.menubar)
     49          self.menuFile.setObjectName("menuFile")
     50          self.menuAbout = QtGui.QMenu(self.menubar)
     51          self.menuAbout.setObjectName("menuAbout")
     52          MainWindow.setMenuBar(self.menubar)
     53          self.statusbar = QtGui.QStatusBar(MainWindow)
     54          self.statusbar.setGeometry(QtCore.QRect(0, 469, 673, 24))
     55          self.statusbar.setObjectName("statusbar")
     56          MainWindow.setStatusBar(self.statusbar)
     57          self.toolBar = QtGui.QToolBar(MainWindow)
     58          self.toolBar.setEnabled(True)
     59          self.toolBar.setGeometry(QtCore.QRect(0, 24, 673, 34))
     60          self.toolBar.setObjectName("toolBar")
     61          MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
     62          self.actionOpen = QtGui.QAction(MainWindow)
     63          icon = QtGui.QIcon()
     64          icon.addPixmap(QtGui.QPixmap(":/ete icons/fileopen.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
     65          self.actionOpen.setIcon(icon)
     66          self.actionOpen.setObjectName("actionOpen")
     67          self.actionPaste_newick = QtGui.QAction(MainWindow)
     68          self.actionPaste_newick.setObjectName("actionPaste_newick")
     69          self.actionSave_image = QtGui.QAction(MainWindow)
     70          icon1 = QtGui.QIcon()
     71          icon1.addPixmap(QtGui.QPixmap(":/ete icons/filesave.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
     72          self.actionSave_image.setIcon(icon1)
     73          self.actionSave_image.setObjectName("actionSave_image")
     74          self.actionSave_region = QtGui.QAction(MainWindow)
     75          self.actionSave_region.setObjectName("actionSave_region")
     76          self.actionBranchLength = QtGui.QAction(MainWindow)
     77          self.actionBranchLength.setCheckable(True)
     78          icon2 = QtGui.QIcon()
     79          icon2.addPixmap(QtGui.QPixmap(":/ete icons/show_dist.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
     80          self.actionBranchLength.setIcon(icon2)
     81          self.actionBranchLength.setObjectName("actionBranchLength")
     82          self.actionZoomIn = QtGui.QAction(MainWindow)
     83          icon3 = QtGui.QIcon()
     84          icon3.addPixmap(QtGui.QPixmap(":/ete icons/zoom_in.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
     85          self.actionZoomIn.setIcon(icon3)
     86          self.actionZoomIn.setObjectName("actionZoomIn")
     87          self.actionZoomOut = QtGui.QAction(MainWindow)
     88          icon4 = QtGui.QIcon()
     89          icon4.addPixmap(QtGui.QPixmap(":/ete icons/zoom_out.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
     90          self.actionZoomOut.setIcon(icon4)
     91          self.actionZoomOut.setObjectName("actionZoomOut")
     92          self.actionETE = QtGui.QAction(MainWindow)
     93          self.actionETE.setObjectName("actionETE")
     94          self.actionForceTopology = QtGui.QAction(MainWindow)
     95          self.actionForceTopology.setCheckable(True)
     96          icon5 = QtGui.QIcon()
     97          icon5.addPixmap(QtGui.QPixmap(":/ete icons/force_topo.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
     98          self.actionForceTopology.setIcon(icon5)
     99          self.actionForceTopology.setObjectName("actionForceTopology")
    100          self.actionSave_newick = QtGui.QAction(MainWindow)
    101          self.actionSave_newick.setIcon(icon1)
    102          self.actionSave_newick.setObjectName("actionSave_newick")
    103          self.actionZoomInX = QtGui.QAction(MainWindow)
    104          icon6 = QtGui.QIcon()
    105          icon6.addPixmap(QtGui.QPixmap(":/ete icons/x_expand.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
    106          self.actionZoomInX.setIcon(icon6)
    107          self.actionZoomInX.setObjectName("actionZoomInX")
    108          self.actionZoomOutX = QtGui.QAction(MainWindow)
    109          icon7 = QtGui.QIcon()
    110          icon7.addPixmap(QtGui.QPixmap(":/ete icons/x_reduce.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
    111          self.actionZoomOutX.setIcon(icon7)
    112          self.actionZoomOutX.setObjectName("actionZoomOutX")
    113          self.actionZoomInY = QtGui.QAction(MainWindow)
    114          icon8 = QtGui.QIcon()
    115          icon8.addPixmap(QtGui.QPixmap(":/ete icons/y_expand.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
    116          self.actionZoomInY.setIcon(icon8)
    117          self.actionZoomInY.setObjectName("actionZoomInY")
    118          self.actionZoomOutY = QtGui.QAction(MainWindow)
    119          icon9 = QtGui.QIcon()
    120          icon9.addPixmap(QtGui.QPixmap(":/ete icons/y_reduce.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
    121          self.actionZoomOutY.setIcon(icon9)
    122          self.actionZoomOutY.setObjectName("actionZoomOutY")
    123          self.actionFit2tree = QtGui.QAction(MainWindow)
    124          icon10 = QtGui.QIcon()
    125          icon10.addPixmap(QtGui.QPixmap(":/ete icons/fit_tree.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
    126          self.actionFit2tree.setIcon(icon10)
    127          self.actionFit2tree.setObjectName("actionFit2tree")
    128          self.actionFit2region = QtGui.QAction(MainWindow)
    129          icon11 = QtGui.QIcon()
    130          icon11.addPixmap(QtGui.QPixmap(":/ete icons/fit_region.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
    131          self.actionFit2region.setIcon(icon11)
    132          self.actionFit2region.setObjectName("actionFit2region")
    133          self.actionRenderPDF = QtGui.QAction(MainWindow)
    134          icon12 = QtGui.QIcon()
    135          icon12.addPixmap(QtGui.QPixmap(":/ete icons/export_pdf.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
    136          self.actionRenderPDF.setIcon(icon12)
    137          self.actionRenderPDF.setObjectName("actionRenderPDF")
    138          self.actionSearchNode = QtGui.QAction(MainWindow)
    139          icon13 = QtGui.QIcon()
    140          icon13.addPixmap(QtGui.QPixmap(":/ete icons/search.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
    141          self.actionSearchNode.setIcon(icon13)
    142          self.actionSearchNode.setObjectName("actionSearchNode")
    143          self.actionClear_search = QtGui.QAction(MainWindow)
    144          icon14 = QtGui.QIcon()
    145          icon14.addPixmap(QtGui.QPixmap(":/ete icons/clean_search.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
    146          self.actionClear_search.setIcon(icon14)
    147          self.actionClear_search.setObjectName("actionClear_search")
    148          self.actionShow_newick = QtGui.QAction(MainWindow)
    149          icon15 = QtGui.QIcon()
    150          icon15.addPixmap(QtGui.QPixmap(":/ete icons/show_newick.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
    151          self.actionShow_newick.setIcon(icon15)
    152          self.actionShow_newick.setObjectName("actionShow_newick")
    153          self.actionShow_node_attributes_box = QtGui.QAction(MainWindow)
    154          self.actionShow_node_attributes_box.setCheckable(True)
    155          self.actionShow_node_attributes_box.setChecked(True)
    156          self.actionShow_node_attributes_box.setObjectName("actionShow_node_attributes_box")
    157          self.actionRender_selected_region = QtGui.QAction(MainWindow)
    158          self.actionRender_selected_region.setIcon(icon12)
    159          self.actionRender_selected_region.setShortcutContext(QtCore.Qt.WidgetShortcut)
    160          self.actionRender_selected_region.setObjectName("actionRender_selected_region")
    161          self.menuFile.addAction(self.actionOpen)
    162          self.menuFile.addAction(self.actionPaste_newick)
    163          self.menuFile.addAction(self.actionSave_newick)
    164          self.menuFile.addAction(self.actionRenderPDF)
    165          self.menuFile.addAction(self.actionRender_selected_region)
    166          self.menuAbout.addAction(self.actionETE)
    167          self.menubar.addAction(self.menuFile.menuAction())
    168          self.menubar.addAction(self.menuAbout.menuAction())
    169          self.toolBar.addAction(self.actionZoomIn)
    170          self.toolBar.addAction(self.actionZoomOut)
    171          self.toolBar.addAction(self.actionFit2tree)
    172          self.toolBar.addAction(self.actionFit2region)
    173          self.toolBar.addAction(self.actionZoomInX)
    174          self.toolBar.addAction(self.actionZoomOutX)
    175          self.toolBar.addAction(self.actionZoomInY)
    176          self.toolBar.addAction(self.actionZoomOutY)
    177          self.toolBar.addAction(self.actionSearchNode)
    178          self.toolBar.addAction(self.actionClear_search)
    179          self.toolBar.addAction(self.actionForceTopology)
    180          self.toolBar.addAction(self.actionBranchLength)
    181          self.toolBar.addAction(self.actionRenderPDF)
    182          self.toolBar.addAction(self.actionShow_newick)
    183
    184          self.retranslateUi(MainWindow)
    185          QtCore.QMetaObject.connectSlotsByName(MainWindow)
    186
    187 -    def retranslateUi(self, MainWindow):
    188          MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "MainWindow", None, QtGui.QApplication.UnicodeUTF8))
    189          self.menuFile.setTitle(QtGui.QApplication.translate("MainWindow", "File", None, QtGui.QApplication.UnicodeUTF8))
    190          self.menuAbout.setTitle(QtGui.QApplication.translate("MainWindow", "About", None, QtGui.QApplication.UnicodeUTF8))
    191          self.toolBar.setWindowTitle(QtGui.QApplication.translate("MainWindow", "toolBar", None, QtGui.QApplication.UnicodeUTF8))
    192          self.actionOpen.setText(QtGui.QApplication.translate("MainWindow", "Open newick tree", None, QtGui.QApplication.UnicodeUTF8))
    193          self.actionOpen.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+O", None, QtGui.QApplication.UnicodeUTF8))
    194          self.actionPaste_newick.setText(QtGui.QApplication.translate("MainWindow", "Paste newick", None, QtGui.QApplication.UnicodeUTF8))
    195          self.actionPaste_newick.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+P", None, QtGui.QApplication.UnicodeUTF8))
    196          self.actionSave_image.setText(QtGui.QApplication.translate("MainWindow", "Save Image", None, QtGui.QApplication.UnicodeUTF8))
    197          self.actionSave_region.setText(QtGui.QApplication.translate("MainWindow", "Save region", None, QtGui.QApplication.UnicodeUTF8))
    198          self.actionSave_region.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+A", None, QtGui.QApplication.UnicodeUTF8))
    199          self.actionBranchLength.setText(QtGui.QApplication.translate("MainWindow", "Show branch info", None, QtGui.QApplication.UnicodeUTF8))
    200          self.actionBranchLength.setShortcut(QtGui.QApplication.translate("MainWindow", "L", None, QtGui.QApplication.UnicodeUTF8))
    201          self.actionZoomIn.setText(QtGui.QApplication.translate("MainWindow", "Zoom in", None, QtGui.QApplication.UnicodeUTF8))
    202          self.actionZoomIn.setShortcut(QtGui.QApplication.translate("MainWindow", "Z", None, QtGui.QApplication.UnicodeUTF8))
    203          self.actionZoomOut.setText(QtGui.QApplication.translate("MainWindow", "Zoom out", None, QtGui.QApplication.UnicodeUTF8))
    204          self.actionZoomOut.setShortcut(QtGui.QApplication.translate("MainWindow", "X", None, QtGui.QApplication.UnicodeUTF8))
    205          self.actionETE.setText(QtGui.QApplication.translate("MainWindow", "ETE", None, QtGui.QApplication.UnicodeUTF8))
    206          self.actionForceTopology.setText(QtGui.QApplication.translate("MainWindow", "Force topology", None, QtGui.QApplication.UnicodeUTF8))
    207          self.actionForceTopology.setToolTip(QtGui.QApplication.translate("MainWindow", "Allows to see topology by setting assuming all branch lenghts are 1.0", None, QtGui.QApplication.UnicodeUTF8))
    208          self.actionForceTopology.setShortcut(QtGui.QApplication.translate("MainWindow", "T", None, QtGui.QApplication.UnicodeUTF8))
    209          self.actionSave_newick.setText(QtGui.QApplication.translate("MainWindow", "Save as newick", None, QtGui.QApplication.UnicodeUTF8))
    210          self.actionZoomInX.setText(QtGui.QApplication.translate("MainWindow", "Increase X scale", None, QtGui.QApplication.UnicodeUTF8))
    211          self.actionZoomOutX.setText(QtGui.QApplication.translate("MainWindow", "Decrease X scale", None, QtGui.QApplication.UnicodeUTF8))
    212          self.actionZoomInY.setText(QtGui.QApplication.translate("MainWindow", "Increase Y scale", None, QtGui.QApplication.UnicodeUTF8))
    213          self.actionZoomOutY.setText(QtGui.QApplication.translate("MainWindow", "Decrease Y scale", None, QtGui.QApplication.UnicodeUTF8))
    214          self.actionFit2tree.setText(QtGui.QApplication.translate("MainWindow", "Fit to tree", None, QtGui.QApplication.UnicodeUTF8))
    215          self.actionFit2tree.setShortcut(QtGui.QApplication.translate("MainWindow", "W", None, QtGui.QApplication.UnicodeUTF8))
    216          self.actionFit2region.setText(QtGui.QApplication.translate("MainWindow", "Fit to selection", None, QtGui.QApplication.UnicodeUTF8))
    217          self.actionFit2region.setShortcut(QtGui.QApplication.translate("MainWindow", "R", None, QtGui.QApplication.UnicodeUTF8))
    218          self.actionRenderPDF.setText(QtGui.QApplication.translate("MainWindow", "Render PDF image", None, QtGui.QApplication.UnicodeUTF8))
    219          self.actionSearchNode.setText(QtGui.QApplication.translate("MainWindow", "Search", None, QtGui.QApplication.UnicodeUTF8))
    220          self.actionSearchNode.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+S", None, QtGui.QApplication.UnicodeUTF8))
    221          self.actionClear_search.setText(QtGui.QApplication.translate("MainWindow", "Clear search", None, QtGui.QApplication.UnicodeUTF8))
    222          self.actionClear_search.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+C", None, QtGui.QApplication.UnicodeUTF8))
    223          self.actionShow_newick.setText(QtGui.QApplication.translate("MainWindow", "Show newick", None, QtGui.QApplication.UnicodeUTF8))
    224          self.actionShow_newick.setShortcut(QtGui.QApplication.translate("MainWindow", "N", None, QtGui.QApplication.UnicodeUTF8))
    225          self.actionShow_node_attributes_box.setText(QtGui.QApplication.translate("MainWindow", "Show node attributes box", None, QtGui.QApplication.UnicodeUTF8))
    226          self.actionRender_selected_region.setText(QtGui.QApplication.translate("MainWindow", "Render selected region", None, QtGui.QApplication.UnicodeUTF8))
    227
    228  import ete_resources_rc
    229